@@ -1,5 +1,5 @@
 # Libsecp256k1-0
-# Copyright (c) 2022 Mystic Technology LLC
+# Copyright (c) 2022 Arctic Technology
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -65,6 +65,10 @@ class Libsecp256k1:
 	def win64bit(self) -> str:
 		return self.get_lib_path('compiled/win64bit/libsecp256k1-0.dll')
 
+	@classmethod
+	def darwin(self) -> str:
+		return self.get_lib_path('compiled/darwin/libsecp256k1.0.dylib')
+
 	@classmethod
 	def docker_compile(self, outpath: str = None, interactive: bool = False, sudo: bool = False) -> dict:
 		dockerhome = '/home/ubuntu/libsecp256k1'
@@ -121,6 +125,8 @@ class Libsecp256k1:
 			library_paths = (self.win32bit(), 'libsecp256k1-0.dll')
 		elif sys.platform in ('windows', 'win32') and platform.architecture()[0] == '64bit':
 			library_paths = (self.win64bit(), 'libsecp256k1-0.dll')
+		elif sys.platform in ('darwin'):
+			library_paths = (self.darwin(), 'libsecp256k1.0.dylib')
 		else:
 			library_paths = (self.unix(), 'libsecp256k1.so.0')
 
